#!/bin/bash

SOURCE="${BASH_SOURCE[0]}" 
while [ -h "$SOURCE" ]; do # resolve $SOURCE until the file is no longer a symlink
  DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )" 
  SOURCE="$(readlink "$SOURCE")" 
  [[ $SOURCE != /* ]] && SOURCE="$DIR/$SOURCE" # if $SOURCE was a relative symlink, we need to resolve it relative to the path where the symlink file was located
done
DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )" 

echo 'Retrieving certificate tarball...'
if hash wget 2>/dev/null; then
  echo 'Wget found...'
  wget https://dist.eugridpma.info/distribution/igtf/current/accredited/igtf-preinstalled-bundle-classic.tar.gz -P $DIR/
  if [ $? -ne 0 ]; then
    echo 'Failed to download certificate tarball!'
    exit 2
  fi
elif hash curl 2>/dev/null; then
  echo 'Curl found...'
  curl https://dist.eugridpma.info/distribution/igtf/current/accredited/igtf-preinstalled-bundle-classic.tar.gz > $DIR/certificates.tar.gz
  if [ $? -ne 0 ]; then
    echo 'Failed to curl certificate tarball!'
    exit 2
  fi
else
  echo 'Neither wget nor curl found! Exit now.' 
  exit 1
fi

BCKP=old-certs.tar.gz.$(date +%s)
echo 'Removing old certificates... (to restore: tar -zxf '$DIR'/'$BCKP' -C '$DIR')'
cd $DIR; tar -zcf $BCKP voms-clients/etc/certificates/ &> /dev/null
rm -rf $DIR/voms-clients/etc/certificates
mkdir $DIR/voms-clients/etc/certificates

for a in `ls -1 $DIR/*.tar.gz`; do echo 'Extracting new certificates...'; tar -zxf $a -C $DIR/voms-clients/etc/certificates; done
rm $DIR/*.tar.gz
echo 'Done!'

